Crate rig_derive

Crate rig_derive 

Attribute Macros

rig_tool
A procedural macro that transforms a function into a portable rig_core::tool::PortableTool, or into the classic contextual rig::tool::Tool when the function accepts classic runtime context.

Derive Macros

Embed
A macro that allows you to implement the rig::embedding::Embed trait by deriving it. Usage can be found below: